@@ -3,7 +3,7 @@ from __future__ import annotations
 import datetime
 import json
 import warnings
-from typing import Optional, Union
+from typing import Optional
 
 import requests
 
@@ -13,7 +13,6 @@ class MouseNotInMTrainError(Exception):
 
 
 class MTrain:
-
     server = "http://mtrain:5000"
 
     @classmethod
@@ -26,10 +25,10 @@ class MTrain:
         # but it doesn't necessarily have to be set on init
         if mouse_id:
             self.mouse_id = mouse_id
-    
+
     def __repr__(self):
         return f"{self.__class__.__name__}({self.mouse_id!r})"
-    
+
     def session(self):
         session = requests.session()
         session.post(
@@ -65,7 +64,7 @@ class MTrain:
         ]
 
     @state.setter
-    def state(self, value: Union[dict, int, str]):
+    def state(self, value: dict | int | str):
         """Allows switching to one of the states in the current regimen.
 
         To change regimen, use set_regimen_and_stage()
@@ -163,7 +162,9 @@ class MTrain:
         )
 
     def set_regimen_and_stage(
-        self, regimen: Union[dict, int, str] = None, stage: Union[dict, int, str] = None
+        self,
+        regimen: Optional[dict | int | str] = None,
+        stage: Optional[dict | int | str] = None,
     ):
         """Requires a regimen dict, id (str/int) or name (str), plus stage dict, id (str/int) or name (str)"""
 
@@ -251,7 +252,7 @@ class MTrain:
                 return item
 
     @stage.setter
-    def stage(self, value: Union[str, int]):
+    def stage(self, value: str | int):
         """Accepts stage id (int/str) or name (str)"""
 
         state_match = None
@@ -280,7 +281,7 @@ class MTrain:
         return self.stage
 
     @script.setter
-    def script(self, value: Union[str, int]) -> dict:
+    def script(self, value: str | int) -> None:
         """Accepts stage id (int/str) or name (str)
         Re-routes to stage property
         """
